==> huaweicloudsdkcdm-3.0.80-py2.py3-none-any.whl: huaweicloudsdkcdm/v1/model/cluster_detail_instance_volume.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ClusterDetailInstanceVolume:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'size': 'int'
    }

    attribute_map = {
        'type': 'type',
        'size': 'size'
    }

    def __init__(self, type=None, size=None):
        """ClusterDetailInstanceVolume - a model defined in huaweicloud sdk"""
        
        

        self._type = None
        self._size = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if size is not None:
            self.size = size

    @property
    def type(self):
        """Gets the type of this ClusterDetailInstanceVolume.

        节点的磁盘类型，只支持本地磁盘

        :return: The type of this ClusterDetailInstanceVolume.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ClusterDetailInstanceVolume.

        节点的磁盘类型，只支持本地磁盘

        :param type: The type of this ClusterDetailInstanceVolume.
        :type: str
        """
        self._type = type

    @property
    def size(self):
        """Gets the size of this ClusterDetailInstanceVolume.

        节点磁盘大小，单位G。

        :return: The size of this ClusterDetailInstanceVolume.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ClusterDetailInstanceVolume.

        节点磁盘大小，单位G。

        :param size: The size of this ClusterDetailInstanceVolume.
        :type: int
        """
        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterDetailInstanceVolume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdm-3.1.9-py2.py3-none-any.whl: huaweicloudsdkcdm/v1/model/cluster_detail_instance_volume.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ClusterDetailInstanceVolume:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'size': 'int'
    }

    attribute_map = {
        'type': 'type',
        'size': 'size'
    }

    def __init__(self, type=None, size=None):
        """ClusterDetailInstanceVolume

        The model defined in huaweicloud sdk

        :param type: 节点的磁盘类型，只支持本地磁盘
        :type type: str
        :param size: 节点磁盘大小，单位G。
        :type size: int
        """
        
        

        self._type = None
        self._size = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if size is not None:
            self.size = size

    @property
    def type(self):
        """Gets the type of this ClusterDetailInstanceVolume.

        节点的磁盘类型，只支持本地磁盘

        :return: The type of this ClusterDetailInstanceVolume.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ClusterDetailInstanceVolume.

        节点的磁盘类型，只支持本地磁盘

        :param type: The type of this ClusterDetailInstanceVolume.
        :type type: str
        """
        self._type = type

    @property
    def size(self):
        """Gets the size of this ClusterDetailInstanceVolume.

        节点磁盘大小，单位G。

        :return: The size of this ClusterDetailInstanceVolume.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ClusterDetailInstanceVolume.

        节点磁盘大小，单位G。

        :param size: The size of this ClusterDetailInstanceVolume.
        :type size: int
        """
        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterDetailInstanceVolume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
